@@ -46,6 +46,9 @@ typedef struct GduDVDSupport GduDVDSupport;
 struct GduLocalJob;
 typedef struct GduLocalJob GduLocalJob;
 
+struct GduXzDecompressor;
+typedef struct GduXzDecompressor GduXzDecompressor;
+
 G_END_DECLS
 
 #endif /* __GDU_TYPES_H__ */
